@@ -11,9 +11,9 @@ envvar_re = re.compile(r'^([A-Za-z_0-9]+)\s*=\s*(.*)$')
 
 MINUTES_SET = list(range(0, 60))
 HOURS_SET = list(range(0, 24))
-DAYS_SET = list(range(0, 32))
+DAYS_SET = list(range(1, 32))
 DOWS_SET = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat']
-MONTHS_SET = list(range(0, 13))
+MONTHS_SET = list(range(1, 13))
 TIME_UNITS_SET = ['daily', 'weekly', 'monthly', 'quarterly', 'semi-annually', 'yearly']
 
 KSH_SHELLS = ['/bin/sh', '/bin/dash', '/bin/ksh', '/bin/bash', '/usr/bin/zsh']
@@ -227,11 +227,16 @@ def parse_time_unit(filename, line, value, values, mapping=int):
     if value == '*':
         return ['*']
     try:
+        base = min(values)
+        # day of weeks
+        if isinstance(base, str):
+            base = 0
         result = sorted(reduce(lambda a, i: a.union(set(i)), list(map(values.__getitem__,
-        list(map(parse_period(mapping), value.split(','))))), set()))
+        list(map(parse_period(mapping, base), value.split(','))))), set()))
     except ValueError:
         result = []
-    if not len(result): log(3, 'garbled time in %s [%s]: %s' % (filename, line, value))
+    if not len(result):
+        log(3, 'garbled time in %s [%s]: %s' % (filename, line, value))
     return result
 
 def month_map(month):
@@ -246,7 +251,7 @@ def dow_map(dow):
     except ValueError:
         return int(dow) % 7
 
-def parse_period(mapping=int):
+def parse_period(mapping=int, base=0):
     def parser(value):
         try:
             range, step = value.split('/')
@@ -262,7 +267,7 @@ def parse_period(mapping=int):
         except ValueError:
             start = end = range
 
-        return slice(mapping(start), mapping(end) + 1, int(step))
+        return slice(mapping(start) - 1 + int(not(bool(base))), mapping(end) + int(not(bool(base))), int(step))
 
     return parser
 
@@ -382,8 +387,15 @@ def generate_timer_unit(job, seq):
                     schedule = job['p']
 
     else:
-        dows = ','.join(job['w'])
-        dows = '' if dows == '*' else dows + ' '
+        if job['w'] == ['*']:
+            dows=''
+        else:
+            dows_sorted = []
+            for day in DOWS_SET:
+                if day in job['w']:
+                    dows_sorted.append(day)
+            dows = ','.join(dows_sorted) + ' '
+
         if 0 in job['M']: job['M'].remove(0)
         if 0 in job['d']: job['d'].remove(0)
         if not len(job['M']) or not len(job['d']) or not len(job['h']) or not len(job['m']):
@@ -400,14 +412,9 @@ def generate_timer_unit(job, seq):
     unit_name = "cron-%s-%s-%s" % (job['j'], job['u'], unit_id)
 
     if not (len(parts) == 1 and os.path.isfile(command)):
-        if "'" not in command:
-            command=job['s'] + " -c '" + command + "'"
-        elif '"' not in command:
-            command=job['s'] + ' -c "' + command + '"'
-        else:
-            with open('%s/%s.sh' % (TARGET_DIR, unit_name), 'w', encoding='utf8') as f:
-                f.write(command)
-            command=job['s'] + ' ' + TARGET_DIR + '/' + unit_name + '.sh'
+        with open('%s/%s.sh' % (TARGET_DIR, unit_name), 'w', encoding='utf8') as f:
+            f.write(command)
+        command=job['s'] + ' ' + TARGET_DIR + '/' + unit_name + '.sh'
 
     with open('%s/%s.timer' % (TARGET_DIR, unit_name), 'w' , encoding='utf8') as f:
         f.write('[Unit]\n')
